@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.122';
+our $VERSION = '0.123';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -427,7 +427,8 @@ is taken into account, as is atmospheric extinction. Non-specular
 flares are calculated by a fairly arbitrary equation whose coefficients
 were fitted to visual flare magnitude estimates collected by Ron Lee
 and made available on the Web by Randy John as part of his skysat
-web site at L<http://home.comcast.net/~skysat/>. Atmospheric extinction
+web site at C<http://home.comcast.net/~skysat/> (missing; see
+L<ACKNOWLEDGMENTS|/ACKNOWLEDGMENTS>). Atmospheric extinction
 is also taken into account for the non-specular flares.
 
 Atmospheric extinction is calculated according to the article by Daniel
@@ -463,10 +464,10 @@ CelesTrak (L<http://celestrak.com/SpaceTrack/query/iridium.txt>), since
 it represents one-stop shopping, and Dr. Kelso has expressed the intent
 to check with Iridium Satellite LLC monthly for status. Mike McCants'
 "Status of Iridium Payloads" at
-L<http://users2.ev1.net/~mmccants/tles/iridium.html> notes that flares
-may be unreliable for spares, so can_flare () returns false for them. If
-this is not what you want, call can_flare with a true value (e.g.
-can_flare(1)).
+C<http://users2.ev1.net/~mmccants/tles/iridium.html> (no longer
+maintained) noted that flares may be unreliable for spares, so can_flare
+() returns false for them. If this is not what you want, call can_flare
+with a true value (e.g. C<can_flare( 1 )>).
 
 Fourth, the Heavens Above definition of 'daytime' differs from mine.
 Heavens Above does not document what their definition is, at least
@@ -1682,12 +1683,12 @@ sub _set_operational_status {
 #
 # Generated by Astro::SpaceTrack
 # $ tools/all_iridium_classic -iridium -indent=0
-# on Fri May 17 18:12:28 2019 GMT
+# on Fri Jun 28 14:43:33 2019 GMT
 #
 # The following static method is UNSUPPORTED, and exists solely for the
 # benefit of xt/author/iridium_status.t. It may be modified or revoked
 # at any time.
-sub __iridium_status_as_of { return( qw{ 46 5 10 16 4 2019 } ) }
+sub __iridium_status_as_of { return( qw{ 55 43 4 28 5 2019 } ) }
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1744,7 +1745,7 @@ __PACKAGE__->status( add => 25171, iridium => 'D', 'Iridium 54', 'Decayed 2019-0
 __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
 __PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
-__PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
+__PACKAGE__->status( add => 25263, iridium => '-', 'Iridium 61', 'Tumbling' );
 __PACKAGE__->status( add => 25272, iridium => 'D', 'Iridium 55', 'Decayed 2019-03-31' );
 __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
 __PACKAGE__->status( add => 25274, iridium => 'D', 'Iridium 58', 'Decayed 2019-04-07' );
@@ -1790,8 +1791,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 
 # Summary:
 # Operational [+]: 0
-#       Spare [S]: 2
-#    Tumbling [-]: 32
+#       Spare [S]: 1
+#    Tumbling [-]: 33
 #     Decayed [D]: 63
 
 1;
@@ -1928,11 +1929,14 @@ whose work this module would never have existed:
 Ron Lee and the members of his team who collected Iridium magnitude
 data.
 
-Randy John, the author of SKYSAT (L<http://home.comcast.net/~skysat/>),
+Randy John, the author of SKYSAT (C<http://home.comcast.net/~skysat/>),
 whose Turbo Pascal implementation of the geometry calculation (at
-L<http://home.comcast.net/~skysat/algo.txt> provided the basic mechanism
+C<http://home.comcast.net/~skysat/algo.txt> provided the basic mechanism
 for my own geometry calculation, and who made Ron Lee's data available
-on the SKYSAT web site.
+on the SKYSAT web site. Unfortunately Comcast has long since stopped
+providing personal pages, and I have found nothing more recent. The
+most-recent capture of this by the Internet Archive's Wayback Machine is
+September 19 2015.
 
 The contributors to the Visual Satellite Observer's Home Page
 (L<http://www.satobs.org/satintro.html>), particularly the
